@@ -1,5 +1,8 @@
 /* ipv6.h
- * Definitions for IPv6 packet disassembly
+ * Definitions of IPv6 address-and-prefix structure, which is what an
+ * FT_IPV6 value is (even if there's no prefix in a packet, those
+ * values can be compared against an address+prefix in a filter
+ * expression).
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,7 +32,7 @@
 #include <wsutil/inet_ipv6.h>
 
 typedef struct {
-	struct e_in6_addr addr;
+	ws_in6_addr addr;
 	guint32 prefix;
 } ipv6_addr_and_prefix;
 
